Module arg

Module arg 

Query argument definitions for chDB.

This module provides types for specifying query arguments such as output format, log level, and custom command-line arguments.

Enums

Arg
Query arguments that can be passed when executing queries.