pub struct ArrowArray { /* private fields */ }Expand description
A handle to an Arrow array.
This is a wrapper around the opaque chdb_arrow_array pointer type.
Arrow arrays contain the actual data in Arrow format.
Safety
The underlying pointer must be valid and must remain valid for the lifetime of this handle. The handle does not take ownership of the Arrow array.
Implementations
Sourceimpl ArrowArray
impl ArrowArray
Sourcepub unsafe fn from_raw(array: *mut chdb_arrow_array_) -> Self
pub unsafe fn from_raw(array: *mut chdb_arrow_array_) -> Self
Create an ArrowArray from a raw chdb_arrow_array pointer.
Safety
The pointer must be valid and point to a valid Arrow array handle. The caller is responsible for ensuring the array remains valid for the lifetime of this handle.
Arguments
array- A raw pointer to achdb_arrow_array
Examples
use chdb_rust::arrow_stream::ArrowArray;
// Assuming you have a valid Arrow array pointer from Arrow C++
// let array_ptr: *mut chdb_arrow_array_ = ...;
// let arrow_array = unsafe { ArrowArray::from_raw(array_ptr) };Trait Implementations
Sourceimpl Clone for ArrowArray
impl Clone for ArrowArray
Sourcefn clone(&self) -> ArrowArray
fn clone(&self) -> ArrowArray
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArrowArray
impl Debug for ArrowArray
impl Copy for ArrowArray
impl Send for ArrowArray