pub struct ArrowStream { /* private fields */ }Expand description
A handle to an Arrow stream.
This is a wrapper around the opaque chdb_arrow_stream pointer type.
Arrow streams are typically created from Arrow C++ or other Arrow implementations.
Safety
The underlying pointer must be valid and must remain valid for the lifetime of this handle. The handle does not take ownership of the Arrow stream.
Implementations
Sourceimpl ArrowStream
impl ArrowStream
Sourcepub unsafe fn from_raw(stream: *mut chdb_arrow_stream_) -> Self
pub unsafe fn from_raw(stream: *mut chdb_arrow_stream_) -> Self
Create an ArrowStream from a raw chdb_arrow_stream pointer.
Safety
The pointer must be valid and point to a valid Arrow stream handle. The caller is responsible for ensuring the stream remains valid for the lifetime of this handle.
Arguments
stream- A raw pointer to achdb_arrow_stream
Examples
use chdb_rust::arrow_stream::ArrowStream;
// Assuming you have a valid Arrow stream pointer from Arrow C++
// let stream_ptr: *mut chdb_arrow_stream_ = ...;
// let arrow_stream = unsafe { ArrowStream::from_raw(stream_ptr) };Trait Implementations
Sourceimpl Clone for ArrowStream
impl Clone for ArrowStream
Sourcefn clone(&self) -> ArrowStream
fn clone(&self) -> ArrowStream
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArrowStream
impl Debug for ArrowStream
impl Copy for ArrowStream
impl Send for ArrowStream