Error

Enum Error 

pub enum Error {
    Unknown,
    NoResult,
    ConnectionFailed,
    InvalidData(String),
    PathError,
    Io(Error),
    Nul(NulError),
    InsufficientPermissions,
    NonUtf8Sequence(FromUtf8Error),
    QueryError(String),
}
Errors that can occur when using chdb-rust.

This enum represents all possible errors that can be returned by the library. Most errors are self-explanatory, with QueryError containing the actual error message from the underlying chDB library.

Variants



Unknown

An unknown error has occurred.



NoResult

No result was returned from the query.



ConnectionFailed

Failed to establish a connection to chDB.



InvalidData(String)

Invalid data was encountered.



PathError

Invalid path was provided.



Io(Error)

An I/O error occurred.



Nul(NulError)

A null byte was found in a string where it’s not allowed.



InsufficientPermissions

Insufficient permissions to access the directory.



NonUtf8Sequence(FromUtf8Error)

The data contains invalid UTF-8 sequences.



QueryError(String)

A query execution error occurred.

This contains the error message from the underlying chDB library, which typically includes details about SQL syntax errors, missing tables, etc.