InputFormat

Enum InputFormat 

pub enum InputFormat {
Show 57 variants TabSeparated, TabSeparatedRaw, TabSeparatedWithNames, TabSeparatedWithNamesAndTypes, TabSeparatedRawWithNames, TabSeparatedRawWithNamesAndTypes, Template, TemplateIgnoreSpaces, CSV, CSVWithNames, CSVWithNamesAndTypes, CustomSeparated, CustomSeparatedWithNames, CustomSeparatedWithNamesAndTypes, Values, JSON, JSONAsString, JSONAsObject, JSONStrings, JSONColumns, JSONColumnsWithMetadata, JSONCompact, JSONCompactColumns, JSONEachRow, JSONStringsEachRow, JSONCompactEachRow, JSONCompactEachRowWithNames, JSONCompactEachRowWithNamesAndTypes, JSONCompactStringsEachRow, JSONCompactStringsEachRowWithNames, JSONCompactStringsEachRowWithNamesAndTypes, JSONObjectEachRow, BSONEachRow, TSKV, Protobuf, ProtobufSingle, ProtobufList, Avro, AvroConfluent, Parquet, ParquetMetadata, ORC, One, Npy, RowBinary, RowBinaryWithNames, RowBinaryWithNamesAndTypes, RowBinaryWithDefaults, Native, CapnProto, LineAsString, Regexp, RawBLOB, MsgPack, MySQLDump, DWARF, Form,
}
Input formats for reading data into chDB.

These formats specify how data should be parsed when reading from files or other sources. See the ClickHouse documentation for details on each format.

Variants



TabSeparated



TabSeparatedRaw



TabSeparatedWithNames



TabSeparatedWithNamesAndTypes



TabSeparatedRawWithNames



TabSeparatedRawWithNamesAndTypes



Template



TemplateIgnoreSpaces



CSV



CSVWithNames



CSVWithNamesAndTypes



CustomSeparated



CustomSeparatedWithNames



CustomSeparatedWithNamesAndTypes



Values



JSON



JSONAsString



JSONAsObject



JSONStrings



JSONColumns



JSONColumnsWithMetadata



JSONCompact



JSONCompactColumns



JSONEachRow



JSONStringsEachRow



JSONCompactEachRow



JSONCompactEachRowWithNames



JSONCompactEachRowWithNamesAndTypes



JSONCompactStringsEachRow



JSONCompactStringsEachRowWithNames



JSONCompactStringsEachRowWithNamesAndTypes



JSONObjectEachRow



BSONEachRow



TSKV



Protobuf



ProtobufSingle



ProtobufList



Avro



AvroConfluent



Parquet



ParquetMetadata



ORC



One



Npy



RowBinary



RowBinaryWithNames



RowBinaryWithNamesAndTypes



RowBinaryWithDefaults



Native



CapnProto



LineAsString



Regexp



RawBLOB



MsgPack



MySQLDump



DWARF



Form

Implementations

Source

impl InputFormat

pub const fn as_str(self) -> &'static str

Get the string representation of the input format.

This returns the format name as it should be used in SQL queries (e.g., in file() function calls).

Returns

Returns the format name as a static string slice.