OutputFormat

Enum OutputFormat 

pub enum OutputFormat {
Show 67 variants TabSeparated, TabSeparatedRaw, TabSeparatedWithNames, TabSeparatedWithNamesAndTypes, TabSeparatedRawWithNames, TabSeparatedRawWithNamesAndTypes, Template, CSV, CSVWithNames, CSVWithNamesAndTypes, CustomSeparated, CustomSeparatedWithNames, CustomSeparatedWithNamesAndTypes, Values, JSON, JSONStrings, JSONColumns, JSONColumnsWithMetadata, JSONCompact, JSONCompactStrings, JSONCompactColumns, JSONEachRow, PrettyJSONEachRow, JSONEachRowWithProgress, JSONStringsEachRow, JSONStringsEachRowWithProgress, JSONCompactEachRow, JSONCompactEachRowWithNames, JSONCompactEachRowWithNamesAndTypes, JSONCompactStringsEachRow, JSONCompactStringsEachRowWithNames, JSONCompactStringsEachRowWithNamesAndTypes, JSONObjectEachRow, BSONEachRow, TSKV, Pretty, PrettyNoEscapes, PrettyMonoBlock, PrettyNoEscapesMonoBlock, PrettyCompact, PrettyCompactNoEscapes, PrettyCompactMonoBlock, PrettyCompactNoEscapesMonoBlock, PrettySpace, PrettySpaceNoEscapes, PrettySpaceMonoBlock, PrettySpaceNoEscapesMonoBlock, Prometheus, Protobuf, ProtobufSingle, ProtobufList, Avro, Parquet, ORC, Npy, RowBinary, RowBinaryWithNames, RowBinaryWithNamesAndTypes, Native, Null, XML, CapnProto, LineAsString, RawBLOB, MsgPack, Markdown, Vertical,
}
Output formats for query results.

These formats specify how query results should be formatted when returned. See the ClickHouse documentation for details on each format.

Variants



TabSeparated



TabSeparatedRaw



TabSeparatedWithNames



TabSeparatedWithNamesAndTypes



TabSeparatedRawWithNames



TabSeparatedRawWithNamesAndTypes



Template



CSV



CSVWithNames



CSVWithNamesAndTypes



CustomSeparated



CustomSeparatedWithNames



CustomSeparatedWithNamesAndTypes



Values



JSON



JSONStrings



JSONColumns



JSONColumnsWithMetadata



JSONCompact



JSONCompactStrings



JSONCompactColumns



JSONEachRow



PrettyJSONEachRow



JSONEachRowWithProgress



JSONStringsEachRow



JSONStringsEachRowWithProgress



JSONCompactEachRow



JSONCompactEachRowWithNames



JSONCompactEachRowWithNamesAndTypes



JSONCompactStringsEachRow



JSONCompactStringsEachRowWithNames



JSONCompactStringsEachRowWithNamesAndTypes



JSONObjectEachRow



BSONEachRow



TSKV



Pretty



PrettyNoEscapes



PrettyMonoBlock



PrettyNoEscapesMonoBlock



PrettyCompact



PrettyCompactNoEscapes



PrettyCompactMonoBlock



PrettyCompactNoEscapesMonoBlock



PrettySpace



PrettySpaceNoEscapes



PrettySpaceMonoBlock



PrettySpaceNoEscapesMonoBlock



Prometheus



Protobuf



ProtobufSingle



ProtobufList



Avro



Parquet



ORC



Npy



RowBinary



RowBinaryWithNames



RowBinaryWithNamesAndTypes



Native



Null



XML



CapnProto



LineAsString



RawBLOB



MsgPack



Markdown



Vertical

Implementations

Source

impl OutputFormat

pub const fn as_str(self) -> &'static str

Get the string representation of the output format.

This returns the format name as it should be used when executing queries.

Returns

Returns the format name as a static string slice.