pub struct ArrowSchema { /* private fields */ }Expand description
A handle to an Arrow schema.
This is a wrapper around the opaque chdb_arrow_schema pointer type.
Arrow schemas define the structure of Arrow data.
Safety
The underlying pointer must be valid and must remain valid for the lifetime of this handle. The handle does not take ownership of the Arrow schema.
Implementations
Sourceimpl ArrowSchema
impl ArrowSchema
Sourcepub unsafe fn from_raw(schema: *mut chdb_arrow_schema_) -> Self
pub unsafe fn from_raw(schema: *mut chdb_arrow_schema_) -> Self
Create an ArrowSchema from a raw chdb_arrow_schema pointer.
Safety
The pointer must be valid and point to a valid Arrow schema handle. The caller is responsible for ensuring the schema remains valid for the lifetime of this handle.
Arguments
schema- A raw pointer to achdb_arrow_schema
Examples
use chdb_rust::arrow_stream::ArrowSchema;
// Assuming you have a valid Arrow schema pointer from Arrow C++
// let schema_ptr: *mut chdb_arrow_schema_ = ...;
// let arrow_schema = unsafe { ArrowSchema::from_raw(schema_ptr) };Trait Implementations
Sourceimpl Clone for ArrowSchema
impl Clone for ArrowSchema
Sourcefn clone(&self) -> ArrowSchema
fn clone(&self) -> ArrowSchema
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArrowSchema
impl Debug for ArrowSchema
impl Copy for ArrowSchema
impl Send for ArrowSchema